# fcmaes
A Python 3 gradient-free optimization library.

- [README](https://github.com/dietmarwo/fast-cma-es/blob/master/README.adoc)
- [Tutorial](https://github.com/dietmarwo/fast-cma-es/blob/master/Tutorial.adoc)
- [Results](https://github.com/dietmarwo/fast-cma-es/blob/master/Results.adoc)
- [PYKEP Gym Results](https://github.com/dietmarwo/fast-cma-es/blob/master/PYKEP.adoc)
- [Constraints](https://github.com/dietmarwo/fast-cma-es/blob/master/Constraints.adoc)
- [Expressions](https://github.com/dietmarwo/fast-cma-es/blob/master/Expressions.adoc)
- [ODE](https://github.com/dietmarwo/fast-cma-es/blob/master/ODE.adoc)